==> jc-1.4.0.tar.gz: javax/net/ssl/TrivialHostnameVerifier.h <==
// class javax.net.ssl.TrivialHostnameVerifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf2136c7d1203ea5 javax_net_ssl_TrivialHostnameVerifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_TrivialHostnameVerifier_H_
#define _JC_javax_net_ssl_TrivialHostnameVerifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_net_ssl_SSLSession$object;

// Typedefs
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs	_jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs	_jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$refs	_jc_javax_net_ssl_TrivialHostnameVerifier$refs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs	_jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$object	_jc_javax_net_ssl_TrivialHostnameVerifier$object;

typedef const struct _jc_javax_net_ssl_TrivialHostnameVerifier$vmethods	_jc_javax_net_ssl_TrivialHostnameVerifier$vmethods;
typedef const struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtable	_jc_javax_net_ssl_TrivialHostnameVerifier$vtable;
typedef const struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtype	_jc_javax_net_ssl_TrivialHostnameVerifier$vtype;

// Constructors
extern void _jc_javax_net_ssl_TrivialHostnameVerifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_TrivialHostnameVerifier$object *);

// Virtual methods
extern jboolean _jc_javax_net_ssl_TrivialHostnameVerifier$method$verify$826a5306d2baface(_jc_env *, struct _jc_javax_net_ssl_TrivialHostnameVerifier$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_TrivialHostnameVerifier$method_info$verify$826a5306d2baface;

// Virtual methods structure
struct _jc_javax_net_ssl_TrivialHostnameVerifier$vmethods {
	jboolean	(*verify$826a5306d2baface)(_jc_env *, struct _jc_javax_net_ssl_TrivialHostnameVerifier$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_TrivialHostnameVerifier$vmethods	javax_net_ssl_TrivialHostnameVerifier;
};

// Vtype
struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_TrivialHostnameVerifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$refs {
    _jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs	javax_net_ssl_TrivialHostnameVerifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs	javax_net_ssl_TrivialHostnameVerifier;
};

// Object instance structure
struct _jc_javax_net_ssl_TrivialHostnameVerifier$object {
	_jc_javax_net_ssl_TrivialHostnameVerifier$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_TrivialHostnameVerifier$vtype	*vtype;
	_jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_TrivialHostnameVerifier$vtype _jc_javax_net_ssl_TrivialHostnameVerifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_TrivialHostnameVerifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_TrivialHostnameVerifier$class_object;

#endif	/* _JC_javax_net_ssl_TrivialHostnameVerifier_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/TrivialHostnameVerifier.h <==
// class javax.net.ssl.TrivialHostnameVerifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf2136c7d1203ea5 javax_net_ssl_TrivialHostnameVerifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_net_ssl_TrivialHostnameVerifier_H_
#define _JC_javax_net_ssl_TrivialHostnameVerifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_net_ssl_SSLSession$object;

// Typedefs
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs	_jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs	_jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$refs	_jc_javax_net_ssl_TrivialHostnameVerifier$refs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs	_jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs;
typedef struct _jc_javax_net_ssl_TrivialHostnameVerifier$object	_jc_javax_net_ssl_TrivialHostnameVerifier$object;

typedef const struct _jc_javax_net_ssl_TrivialHostnameVerifier$vmethods	_jc_javax_net_ssl_TrivialHostnameVerifier$vmethods;
typedef const struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtable	_jc_javax_net_ssl_TrivialHostnameVerifier$vtable;
typedef const struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtype	_jc_javax_net_ssl_TrivialHostnameVerifier$vtype;

// Constructors
extern void _jc_javax_net_ssl_TrivialHostnameVerifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_TrivialHostnameVerifier$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_net_ssl_TrivialHostnameVerifier$method$verify$826a5306d2baface(_jc_env *, struct _jc_javax_net_ssl_TrivialHostnameVerifier$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_TrivialHostnameVerifier$method_info$verify$826a5306d2baface;

// Virtual methods structure
struct _jc_javax_net_ssl_TrivialHostnameVerifier$vmethods {
	jboolean	(*verify$826a5306d2baface)(_jc_env *, struct _jc_javax_net_ssl_TrivialHostnameVerifier$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ssl_TrivialHostnameVerifier$vmethods	javax_net_ssl_TrivialHostnameVerifier;
};

// Vtype
struct _jc_javax_net_ssl_TrivialHostnameVerifier$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_TrivialHostnameVerifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$refs {
    _jc_javax_net_ssl_TrivialHostnameVerifier$sub_refs	javax_net_ssl_TrivialHostnameVerifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ssl_TrivialHostnameVerifier$sub_nonrefs	javax_net_ssl_TrivialHostnameVerifier;
};

// Object instance structure
struct _jc_javax_net_ssl_TrivialHostnameVerifier$object {
	_jc_javax_net_ssl_TrivialHostnameVerifier$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_TrivialHostnameVerifier$vtype	*vtype;
	_jc_javax_net_ssl_TrivialHostnameVerifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_TrivialHostnameVerifier$vtype _jc_javax_net_ssl_TrivialHostnameVerifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_TrivialHostnameVerifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_TrivialHostnameVerifier$class_object;

#endif	/* _JC_javax_net_ssl_TrivialHostnameVerifier_H_ */
